Enum mega::LastModified
source · pub enum LastModified {
Now,
Set(DateTime<Utc>),
}Expand description
Represents the last modified date to set for a newly uploaded MEGA node.
Variants
Now
Set the last modified date to the current time of the upload.
Set(DateTime<Utc>)
Set the last modified date to the explicitely-specified time.
Implementations