Struct mega::Node

source ·
pub struct Node { /* private fields */ }
Represents a node stored in MEGA (either a file or a folder).

Implementations

source

impl Node

source

pub fn name(&self) -> &str

Returns the name of the node.

source

pub fn handle(&self) -> &str

Returns the handle of the node.

source

pub fn owner(&self) -> &str

Returns the user handle of the owner of the node.

source

pub fn size(&self) -> u64

Returns the size (in bytes) of the node.

source

pub fn kind(&self) -> NodeKind

Returns the kind of the node.

source

pub fn parent(&self) -> Option<&str>

Returns the handle of the node’s parent.

source

pub fn children(&self) -> &[String]

Returns the handles of the node’s children.

source

pub fn modified_at(&self) -> Option<DateTime<Utc>>

Returns the last modified date of the node.

source

pub fn created_at(&self) -> Option<DateTime<Utc>>

Returns the creation date of the node.

source

pub fn download_id(&self) -> Option<&str>

Returns the ID of the public link this node is from.

source

pub fn aes_key(&self) -> &[u8; 16]

Returns the AES key data of the node.

source

pub fn aes_iv(&self) -> Option<&[u8; 8]>

Returns the AES IV data of the node.

source

pub fn condensed_mac(&self) -> Option<&[u8; 8]>

Returns the full-coverage condensed MAC signature of the node.

source

pub fn sparse_checksum(&self) -> Option<&[u8; 16]>

Returns the sparse CRC32-based checksum of the node.

source

pub fn has_thumbnail(&self) -> bool

Returns whether this node has a associated thumbnail.

source

pub fn has_preview_image(&self) -> bool

Returns whether this node has an associated preview image.