pub struct Node { /* private fields */ }Expand description
Represents a node stored in MEGA (either a file or a folder).
Implementations
sourceimpl Node
impl Node
sourcepub fn modified_at(&self) -> Option<DateTime<Utc>>
pub fn modified_at(&self) -> Option<DateTime<Utc>>
Returns the last modified date of the node.
sourcepub fn created_at(&self) -> Option<DateTime<Utc>>
pub fn created_at(&self) -> Option<DateTime<Utc>>
Returns the creation date of the node.
sourcepub fn download_id(&self) -> Option<&str>
pub fn download_id(&self) -> Option<&str>
Returns the ID of the public link this node is from.
sourcepub fn condensed_mac(&self) -> Option<&[u8; 8]>
pub fn condensed_mac(&self) -> Option<&[u8; 8]>
Returns the full-coverage condensed MAC signature of the node.
sourcepub fn sparse_checksum(&self) -> Option<&[u8; 16]>
pub fn sparse_checksum(&self) -> Option<&[u8; 16]>
Returns the sparse CRC32-based checksum of the node.
sourcepub fn has_thumbnail(&self) -> bool
pub fn has_thumbnail(&self) -> bool
Returns whether this node has a associated thumbnail.
sourcepub fn has_preview_image(&self) -> bool
pub fn has_preview_image(&self) -> bool
Returns whether this node has an associated preview image.